
.. _wpiutil_api:

WPIUtil API
-----------

The C++ version of the WPIUtil library contains various utilities that
user code and WPILib can use to accomplish common tasks that aren't 
necessarily provided by the C++ standard library.

Much of the content in WPIUtil is not useful for Python teams, so we
don't provide access to most of WPIUtil directly. Luckily, RobotPy teams have
access to the full Python standard library, which has many of the same types
of things in it.

.. note:: If there's something in WPIUtil that you need access to from Python
          and it's not documented here, please `file an issue on github
          <https://github.com/robotpy/robotpy-wpiutil/issues>`_!

.. toctree::

  wpiutil
  wpiutil.log
  wpiutil.sync
